/**
 * @file	nscharset.h
 * @brief	#NSCharacterSet class definition.
 * @date	2004.02.22
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *   #NSCharacterSet class definition.
 *   #NSCharacterSet operates black box memory object.
 */

#ifndef NSCHARSET_H_INCLUDED
#define NSCHARSET_H_INCLUDED

#include <Cacao/nsobject.h>

/** Function to test the character */
typedef gboolean (*NSCharsetTestFunc)(gunichar c) ;

/**
 * @brief	#NSCharacterSet class operates the set of special 
 *		characters of unicode.
 * @par Description
 *   #NSCharacterSet class operates the set of special characters of unicode.
 */
@interface NSCharacterSet : NSObject 
{
	/** Function to test the character */
	NSCharsetTestFunc	test_func ;
}

  /**
   * @brief	Set of alphabet and number character.
   * @return	Set of alphabet and number character.
   * @par Description
   *    Set of alphabet and number character.
   */
  + alphanumericCharacterSet ;

  /**
   * @brief	Set of alphabet and number character.
   * @return	Set of alphabet and number character.
   * @par Description
   *    Set of alphabet and number character.
   */
  + whitespaceAndNewlineCharacterSet ;

  /**
   * @brief	Generate empty #NSCharacterSet object.
   * @result	Generated object.
   * @par Description
   *   Generate empty NSCharacterSet object.
   */
  - init ;

  /**
   * @brief	Generate #NSCharacterSet object with test function.
   * @param	func Source function to test character.
   * @par Description
   *   Generate #NSCharacterSet object with test function.
   *   This method is depend on Glib library and is not implemented by Cocoa.
   * @warning
   *   This method is depend on Glib library and is not implemented by Cocoa.
   *   Do not use outside of this library.
   */
  - initWithTestFunc: (NSCharsetTestFunc) func ;

  /**
   * @brief	Release the content of CSV data.
   * @par Description
   *   Release the content of CSV data.
   */
  - (void) dealloc ;

  /**
   * @brief	Check the character belong to this character set or not.
   * @retval	true The parameter belongs to this character set.
   * @retval	false The parameter DOES NOT belong to this character set.
   * @par Description
   *   Check the character belong to this character set or not.
   */
  - (BOOL) characterIsMember: (unichar_t) c ;

@end

#endif /* NSCHARSET_H_INCLUDED */

