/**
 * @file	nsdata.h
 * @brief	#NSData class definition.
 * @date	2004.02.14
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *   #NSData class definition.
 *   #NSData operates black box memory object.
 */

#ifndef NSDATA_H_INCLUDED
#define NSDATA_H_INCLUDED

#include <Cacao/nsobject.h>

/**
 * @brief	#NSData class operates the information for command line options.
 * @par Description
 *   NSData class operates the information for command line options.
 */
@interface NSData : NSObject 
{
	/** Pointer of memory object */
	void * 		memory_object ;
	/** Size of memory object */
	size_t		object_length ;
}

  /**
   * @brief	Make empty data.
   * @result	Empty NSData object.
   * @par Description
   *   Make empty data.
   */
  + data ;

  /**
   * @brief	Make given size and content data.
   * @result	NSData object contains copy of input data.
   * @param	bytes Pointer of source data.
   * @param	length Size of source data.
   * @par Description
   *   Make given size and content data.
   */
  + dataWithBytes: (const void *) bytes length: (size_t) length ;

  /**
   * @brief	Initialize NSData instance by given data.
   * @result	The object itself.
   * @param	bytes Source data.
   * @param	length Size of source data.
   * @par Description
   *   Initialize NSData instance by given data.
   *   <b>Warning</b>:
   *   You have to give memory object which allocated malloc().
   */
  + dataWithBytesNoCopy: (void *) bytes length: (size_t) length ;

  /**
   * @brief	Generate empty NSData object.
   * @result	Generated object.
   * @par Description
   *   Generate empty NSData object.
   */
  - init ;

  /**
   * @brief	Initialize NSData instance by given data.
   * @result	The object itself.
   * @param	bytes Source data.
   * @param	length Size of source data.
   * @par Description
   *   Initialize NSData instance by given data.
   *   <b>Warning</b>:
   *   You have to give memory object which allocated malloc().
   */
  - initWithBytesNoCopy: (void *) bytes length: (size_t) length ;

  /**
   * @brief	Initialize NSData instance by given data.
   * @result	The object itself.
   * @param	bytes Source data.
   * @param	length Size of source data.
   * @par Description
   *   Initialize NSData instance by given data.
   */
  - initWithBytes: (const void *) bytes length: (size_t) length ;

  /**
   * @brief	Release the content of CSV data.
   * @par Description
   *   Release the content of CSV data.
   */
  - (void) dealloc ;

  /**
   * @brief	Get the content of data.
   * @result	Pointer of the data.
   * @par Description
   *   Get the content of data.
   */
  - (const void *) bytes ;

  /**
   * @brief	Return the length of content data.
   * @par Description
   *   Return the length of content data.
   */
  - (size_t) length ;
@end

#endif /* NSDATA_H_INCLUDED */

