/**
 * @file	nsfilehandle.h
 * @brief	#NSFileHandle class definition.
 * @date	2004.02.14
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *   #NSFileHandle class definition.
 *   #NSFileHandle class operates data file accessing.
 */

#ifndef NSFILEHANDLE_H_INCLUDED
#define NSFILEHANDLE_H_INCLUDED

#include <Cacao/nsobject.h>

/** Imported class types for #NSFileHandle */
@class	NSString, NSData ;

/**
 * @brief	#NSFileHandle operates data file.
 * @par Description
 *    #NSFileHandle operates data file.
 */
@interface NSFileHandle : NSObject 
{
	/** Pointer of data stream */
	FILE *		file_pointer ;
}

 /**
  * @brief	Generate file hadler to read a file.
  * @return	Generated object.
  * @param	path File name with path to read.
  *             if you pass null, standard input is used.
  * @par Description
  *   Generate file hadler to read a file.
  *   If you pass null pointer as <code>path</code>,
  *   standard input is used to read the file.
  */
 + fileHandleForReadingAtPath: (NSString *) path ;

 /**
  * @brief	Generate file hadler to write a file.
  * @return	Generated NSFileHandler object.
  * @param	path File name with path to write.
  * @par Description
  *   Generate file hadler to write a file.
  */
 + fileHandleForWritingAtPath: (NSString *) path ;

 /**
  * @brief	Generate file hadler to update a file.
  * @return	Generated NSFileHandler object.
  * @param	path File name with path to update.
  * @par Description
  *   Generate file hadler to update a file.
  */
 + fileHandleForUpdatingAtPath: (NSString *) path ;

  /**
   * @brief	Initialize NSFileHandle instance
   * @return	The object itself.
   * @par Description
   *   Initialize NSFileHandle instance.
   */
  - initFileHandle: (FILE *) fp ;

  /**
   * @brief	Release the content of CSV data.
   * @par Description
   *   Release the content of CSV data.
   */
  - (void) dealloc ;

  /**
   * @brief	Read all data in the file to read.
   * @return	Content data of the file.
   * @par Description
   *   Read all data in the file to read.
   */
  - (NSData *) readDataToEndOfFile ;

@end

#endif /* NSFILEHANDLE_H_INCLUDED */

