/**
 * @file	nsfilemanager.h
 * @brief	#NSFileManager class definition.
 * @date	2004.02.14
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *   #NSFileManager class definition.
 *   #NSFileManager controls files and directories.
 */

#ifndef NSFILEMANAGER_H_INCLUDED
#define NSFILEMANAGER_H_INCLUDED

#include <Cacao/nsobject.h>

@class	NSString ;

/**
 * @brief	#NSFileManager class controls files and directories.
 * @par Description
 *   #NSFileManager class controls files and directories.
 * @warning
 *   If you want to access contents of the file, see #NSFileHandle class.
 */
@interface NSFileManager : NSObject 
{
}

  /**
   * @brief	Initialize file manager before starting main program.
   * @par Description
   *   Initialize file manager before starting main program.
   */
  + initialize ;

  /**
   * @brief	Get default system file manager.
   * @par Description
   *   Get default systtem file manager.
   */
  + (NSFileManager *) defaultManager ;

  /**
   * @brief	Check the existence of file.
   * @return	True when the file is found.
   * @par Description
   *   Check the existence of file.
   */
  - (BOOL) fileExistAtPath: (NSString *) string ;

@end

#endif /* NSFILEMANAGER_H_INCLUDED */

