/**
 * @file	nsmutablearray.h
 * @brief	#NSMutableArray class definition.
 * @date	2004.02.14
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *   #NSMutableArray class definition.
 *   #NSMutableArray operates fixed size array.
 */

#ifndef NSMUTABLEARRAY_H_INCLUDED
#define NSMUTABLEARRAY_H_INCLUDED

#include <Cacao/nsarray.h>

/**
 * @brief	#NSMutableArray class operates array of objects
 * @par Description
 *    #NSMutableArray class operates array of objects. 
 *    The number of elements in an array is can by changed dynamically.
 */
@interface NSMutableArray : NSArray 
{
	/** Real number of items in array. */
	uint_t	max_count ;
}

  /**
   * @brief	Make the array which has <code>num</code> objects.
   * @par Description
   *   Make the array which has <code>num</code> object.
   *   All initial member is initialized to nil.
   */
  + arrayWithCapacity: (uint_t) num ;

  /**
   * @brief	Initialize #NSMutableArray instance.
   * @par Description
   *   Initialize #NSMutableArray instance with <code>num</code>
   *   slots. The number can be changed.
   */
  - initWithCapacity: (uint_t) num ;

  /**
   * @brief	Release the array and it's contents.
   * @par Description
   *   Release the array and it's contents.
   */
  - (void) dealloc ;

  /**
   * @brief	Add object as the last item of array.
   * @par Description
   *   Add object as the last item of array.
   */
  - (void) addObject: (id) obj ;

  /**
   * @brief	Append all objects in source array.
   * @param	src Source array
   * @par Description
   *    Append all objects in source array.
   */
  - (void) addObjectsFromArray: (NSArray *) src ;

  /**
   * @brief	Insert new object into the given position.
   * @param	obj Source object to add.
   * @param	index Index to add object.
   * @par Description
   *   Insert new object into the given position.
   *   The position is defined by parameter <code>index</code>.
   *   All items after new objects are shifted +1.
   */
  - (void) insertObject: (id) obj atIndex: (uint_t) index ;

  /**
   * @brief	Replace object at given index.
   * @param	index Source index.
   * @param	obj Source object to replace.
   */
  - (void) replaceObjectAtIndex: (uint_t) index withObject: (id) obj ;

  /**
   * @brief	Remove an object in array.
   * @param 	index Target index number.
   * @par Description
   *    Remove an object in array.
   *    If the index value is invalid for the array,
   *    error is occured.
   */
  - removeObjectAtIndex: (uint_t) index ;

@end

#endif /* NSMUTABLEARRAY_H_INCLUDED */

