/**
 * @file	nsmutablestring.h
 * @brief	#NSMutableString class definition.
 * @date	2004.02.14
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *   #NSString class definition.
 *   #NSString operates unicode string data.
 */

#ifndef NSMUTABLESTRING_H_INCLUDED
#define NSMUTABLESTRING_H_INCLUDED

#include <Cacao/nsstring.h>

/**
 * @brief	Unicode string operation class.
 * @par Description
 *   #NSString operates unicode string.
 */
@interface NSMutableString : NSString 
{
}

  /**
   * @brief	Initialize string object.
   * @return	Generated object.
   * @par Description
   *   Initialize unicode string object.
   *   The empty string is set.
   */
  - init ;

  /**
   * @brief	Release resource for the object.
   * @par Description
   *   Release resource for the object.
   */
  - (void) dealloc ;

  /**
   * @brief	Set new string to this object.
   * @param	src Source string.
   * @par Description
   *   Set new string to this object.
   */
  - (void) setString: (NSString *) src ;

  /**
   * @brief	Replace substring at the range by the new string.
   * @param	range Range of substring.
   * @param	substr Substring.
   * @par Description
   *   Replace substring at the range by the new string.
   */
  - (void) replaceCharactersInRange: (NSRange) range 
      byString: (NSString *) substr ;

@end

#endif /* NSMUTABLESTRING_H_INCLUDED */

