/**
 * @file	nsobject.h
 * @brief	#NSObject class definition.
 * @date	2004.02.14
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *   #NSObject class definition.
 *   #NSObject class is a super class of all other classes.
 */

#ifndef NSOBJECT_H_INCLUDED
#define NSOBJECT_H_INCLUDED

#include <Cacao/cacao-sysdep.h>
#include <Cacao/nstypes.h>

/**
 * @brief 	#NSObject class.
 * @par Description
 *    #NSObject class is a super class of all other classes.
 *    This class operates allocation and deallocation of class object.
 *    All classes must inherit this class.
 */
@interface NSObject : OBJECT
{
	/** Reference count */
	int		ref_count ;
}

  /**
   * @brief	Initialize instance of #NSObject class.
   * @return	New object.
   * @par Description
   *   Initialize instance of #NSObject class.
   */
  - init ;
  
  /**
   * @brief	Release resource for the object.
   * @par Description
   *   Release resource for the object.
   */
  - (void) dealloc ;

  /**
   * @brief	Increment the reference count.
   * @par Description
   *   Increment the reference count.
   *   This method is supported only Unix systems. Not MacOS-X.
   */
  - retain ;
  
  /**
   * @brief	Decrement the reference count.
   * @par Description
   *   Decrement the reference count.
   *   If the reference count is zero, the object is disposed.
   *   This method is supported only Unix systems. Not MacOS-X.
   */
  - (oneway void) release ;

@end

#endif /* NSOBJECT_H_INCLUDED */

